@@ -43,8 +43,9 @@ class BaseClient(object):
         if not auth_key_filepath:
             raise ImproperlyConfigured("You must provide a path to a file containing the auth key")
 
-        if apns_push_type not in ["alert", "background"]:
-            raise AttributeError("Please choice alert or background")
+        if apns_push_type not in ["alert", "background", "voip"]:
+            # https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/sending_notification_requests_to_apns/
+            raise AttributeError("Please choice alert, background or voip")
 
         self.auth_key = self._create_auth_key(auth_key_filepath)
         self.bundle_id = bundle_id
